#-----------------------------------------------------------------------
# File    : lvq.mak
# Contents: build learning vector quantization visualization program
# Author  : Christian Borgelt
# History : 2003.01.28 file created
#           2006.07.20 adapted to Visual Studio 8
#           2016.04.20 completed dependencies on header files
#-----------------------------------------------------------------------
THISDIR  = ..\..\lvqd\src
UTILDIR  = ..\..\util\src
TABLEDIR = ..\..\table\src
DRAWDIR  = ..\..\draw\src

CC       = cl.exe
DEFS     = /D WIN32 /D NDEBUG /D _WINDOWS /D _CRT_SECURE_NO_WARNINGS
CFLAGS   = /nologo /W3 /O2 /GS- $(DEFS) /c
INCS     = /I $(UTILDIR) /I $(TABLEDIR) /I $(DRAWDIR)

RSC      = rc.exe
LD       = link.exe
RFLAGS   = /l 0x407 /d NDEBUG
LDFLAGS  = /nologo /subsystem:windows /incremental:no
LIBS     = user32.lib comdlg32.lib gdi32.lib

HDRS     = $(UTILDIR)\fntypes.h    $(UTILDIR)\scanner.h    \
           $(UTILDIR)\tabread.h    $(TABLEDIR)\attset.h    \
           $(TABLEDIR)\table.h     $(TABLEDIR)\tab4vis.h   \
           lvqd.h wlvq.rh
OBJS     = $(UTILDIR)\arrays.obj   $(UTILDIR)\escape.obj   \
           $(UTILDIR)\tabread.obj  $(UTILDIR)\scform.obj   \
           $(TABLEDIR)\attset1.obj $(TABLEDIR)\attset2.obj \
           $(TABLEDIR)\table1.obj  $(TABLEDIR)\tab2ro.obj  \
           $(TABLEDIR)\tab4vis.obj $(DRAWDIR)\wshades.obj  \
           lvqd.obj wlvq.obj wlvq.res
PRGS     = wlvq.exe

#-----------------------------------------------------------------------
# Build Program
#-----------------------------------------------------------------------
all:          $(PRGS)

wlvq.exe:     $(OBJS)
	$(LD) $(LDFLAGS) $(OBJS) $(LIBS) /out:$@

#-----------------------------------------------------------------------
# Main Program
#-----------------------------------------------------------------------
wlvq.obj:     $(HDRS)
wlvq.obj:     wlvq.c lvqd.mak
	$(CC) $(CFLAGS) $(INCS) wlvq.c /Fo$@

lvqd.obj:     $(HDRS)
lvqd.obj:     lvqd.h lvqd.c lvqd.mak
	$(CC) $(CFLAGS) $(INCS) lvqd.c /Fo$@

#-----------------------------------------------------------------------
# Resources
#-----------------------------------------------------------------------
wlvq.res:     wlvq.rh wlvq.rc lvqd.mak
	$(RSC) $(RFLAGS) /fo$@ wlvq.rc

#-----------------------------------------------------------------------
# External Modules
#-----------------------------------------------------------------------
$(UTILDIR)\arrays.obj:
	cd $(UTILDIR)
	$(MAKE) /f util.mak arrays.obj
	cd $(THISDIR)
$(UTILDIR)\escape.obj:
	cd $(UTILDIR)
	$(MAKE) /f util.mak escape.obj
	cd $(THISDIR)
$(UTILDIR)\tabread.obj:
	cd $(UTILDIR)
	$(MAKE) /f util.mak tabread.obj
	cd $(THISDIR)
$(UTILDIR)\scform.obj:
	cd $(UTILDIR)
	$(MAKE) /f util.mak scform.obj
	cd $(THISDIR)
$(TABLEDIR)\attset1.obj:
	cd $(TABLEDIR)
	$(MAKE) /f table.mak attset1.obj
	cd $(THISDIR)
$(TABLEDIR)\attset2.obj:
	cd $(TABLEDIR)
	$(MAKE) /f table.mak attset2.obj
	cd $(THISDIR)
$(TABLEDIR)\attset3.obj:
	cd $(TABLEDIR)
	$(MAKE) /f table.mak attset3.obj
	cd $(THISDIR)
$(TABLEDIR)\table1.obj:
	cd $(TABLEDIR)
	$(MAKE) /f table.mak table1.obj
	cd $(THISDIR)
$(TABLEDIR)\tab2ro.obj:
	cd $(TABLEDIR)
	$(MAKE) /f table.mak tab2ro.obj
	cd $(THISDIR)
$(TABLEDIR)\tab4vis.obj:
	cd $(TABLEDIR)
	$(MAKE) /f table.mak tab4vis.obj
	cd $(THISDIR)
$(DRAWDIR)\wshades.obj:
	cd $(DRAWDIR)
	$(MAKE) /f draw.mak wshades.obj
	cd $(THISDIR)

#-----------------------------------------------------------------------
# Install
#-----------------------------------------------------------------------
install:
	-@copy $(PRGS) ..\..\..\bin

#-----------------------------------------------------------------------
# Clean up
#-----------------------------------------------------------------------
clean:
	$(MAKE) /f lvqd.mak localclean
	cd $(UTILDIR)
	$(MAKE) /f util.mak clean
	cd $(TABLEDIR)
	$(MAKE) /f table.mak localclean
	cd $(DRAWDIR)
	$(MAKE) /f draw.mak clean
	cd $(THISDIR)

localclean:
	-@erase /Q *~ *.obj *.idb *.pch *.res $(PRGS)
